<?php
    /**
     * Plugin Name: Story Show Gallery
     * Plugin URI: https://ssg.flor.cz/wordpress/
     * Description: Vertical photo gallery with optimally placed captions, full screen lightbox, minimalist, no ugly arrows. 
     * Version: 1.6.0
     * Author: Roman Flössler
     * Author URI: https://ssg.flor.cz/
     * License: GPL-2.0+
     * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
     */

    defined( 'ABSPATH' ) or die( 'Only for Wordpress' );
    
    /* Adding Submenu under Settings Tab */
        
    function ssg_add_menu() {
        add_submenu_page ( 'options-general.php', 'Story Show Gallery', 'Story Show Gallery', 'manage_options', 'story-show-gallery', 'ssg_admin_page_render' );
    }
    add_action ( 'admin_menu', 'ssg_add_menu' );

    
    /* Settings page - HTML and form   */

    function ssg_admin_page_render() {
        $ssg_url = plugin_dir_url( __FILE__ );
        $ssg_configURL = admin_url('plugin-editor.php?file=story-show-gallery%2Fssg-js%2Fssg_cfg.js&plugin=story-show-gallery%2Fstory-show-gallery.php', 'admin' );
?>

        <div class="wrap">
            <h1>
                Story Show Gallery
            </h1><br />
            <p class="text green">&#10003; Story Show Gallery is now active. Photos from Wordpress galleries are opening into SSG lightbox. 
            </p>
            <p class="text crucial">
                SSG uses standard WordPress gallery, so create galleries as usual.
                <br /> <br /> <strong class="important">Important!</strong> If you use new Gutenberg gallery, 
                SSG will open only if you set this gallery's option: <img src="<?php echo $ssg_url; ?>img/link-to-media-file.png">
                <br /> You can open a single image into SSG too. Use the same option "Link to: Media file", but in the settings of that image.
            </p>

            <p class="text crucial">Write an image caption into an image's
                <strong class="important">Alt text field</strong>. It is in the gallery/image options.
                <a href="https://roman-flossler.github.io/StoryShowGallery/wordpress/#caption" target="_blank">How to easily caption multiple images</a>.<br>
                If you have captions in other field, you can use <a href="https://wordpress.org/plugins/pb-seo-friendly-images/" target="_blank">PB SEO plugin</a> to auto fill alt text fields. It'll help your site rank better in Google.</p>
            </p>

            <form method="post" action="options.php">
<?php			
                    settings_fields ( "ssg_fields" );
                    do_settings_sections ( "story-show-gallery" );
                    submit_button ();
?>
            <p>Complete clickable configuration is not done yet, but in source you can access <a href="<?php echo $ssg_configURL; ?>" target="_blank">
            ⚙️<strong class="important">SSG configuration</strong> - watermark settings, themes, language localization, etc.</a></p>

            </form>

            <br>
            
            <!--div id="feedback" >
            <p class="text" style='color:#009a0c'>
                You can send me feedback (problems, features you miss):
            </p>
                <form action="https://ssg.flor.cz/email.php" method="post">
                    <textarea name="message" rows="3" cols="88"> If you want to uninstall this plugin, I will be glad if you write me why:</textarea>
                    <input type="submit" value="Send message">
                </form>
            </div>
                
                < If you like this plugin, please give it a 
                <a target="_blank" href="https://wordpress.org/support/plugin/story-show-gallery/reviews/?rate=5#new-post">5-star rating »</a -->
            

            <h3>Controlling the gallery:</h3>
            <p class="text">
                You can control SSG by CSS classes. The <strong class="important">nossg</strong> 
                class selectively deactivate SSG for some images or entire gallery.<br />
                The <strong class="important">gossg</strong> class will show image only if a user clicks on it. The <strong class="important">fs</strong> 
                class activates fullscreen mode for single images. <br />
                <img src="<?php echo $ssg_url; ?>img/link-css-class.png">&nbsp;&nbsp;
                <a href="https://roman-flossler.github.io/StoryShowGallery/wordpress/#cssclasses" target="_blank">See short tutorial</a> <br />
                SSG has four visual themes. You can set a global theme in the configuration or set a theme individualy for each gallery. <br />
                Use these classes: <strong class="important">ssglight</strong>, <strong class="important">ssgdim</strong>, 
                <strong class="important">ssgdark</strong> and <strong class="important">ssgblack</strong>. 
            </p>

            <h3>A couple of useful tips:</h3>

            <p class="text">
                Story Show Gallery supports Google Analytics - 
                <a target="_blank" href="https://roman-flossler.github.io/StoryShowGallery/wordpress/#Analytics">
                find out, how long site visitors view each photo</a> <br />
                How to <a target="_blank" href="https://roman-flossler.github.io/StoryShowGallery/wordpress/#deeplink">
                deep link into Story Show Gallery</a> to show a particular photo.
            </p>
         
        </div>

        <div id="ssg-aside">
            <div class="ssg-box logo">
            <img src="<?php echo $ssg_url; ?>img/ssg-logo.jpg" ></a>
            </div>

            <div class="ssg-box">        
                <br><p>
                You can use Story Show Gallery also outside of Wordpress - <a href="https://ssg.flor.cz/" target="_blank">it is easy to implement</a>
                </p>

            </div>
            <div class="ssg-box donate">
                <p>If you like my WordPress plugins and want to support my work you can send a donation via PayPal.</p>
                <a href="https://www.paypal.me/FlorSSG" target="_blank" >
                <img src="<?php echo $ssg_url; ?>img/donate.png" alt="" width="99" height="49"></a>
            </div>
        </div>

        <p class="author"><a href="https://ssg.flor.cz/wordpress/" target="_blank"> Story Show Gallery</a> by Roman Flössler</p> 
<?php
    }

    /* Init setting section, Init setting field and register settings page */
    
    function ssg_settings_form() {
        add_settings_section ( 'ssg_fields', '', null, 'story-show-gallery' );
        add_settings_field ( 'SSG-3danim-checkbox', 'Thumbnails settings:', 'ssg_output_checkbox', 'story-show-gallery', 'ssg_fields' );
        register_setting ( 'ssg_fields', 'SSG-3danim-checkbox' );
        add_settings_field ( 'SSG-CDN-checkbox', 'Faster loading:', 'ssg_output_CDNchoice', 'story-show-gallery', 'ssg_fields' );
        register_setting ( 'ssg_fields', 'SSG-CDN-checkbox' );
    }
    add_action ( 'admin_init', 'ssg_settings_form' );
    
    
    /*  Add checkbox to settings page  */
    
    function ssg_output_checkbox() {
        $checkboxvalue = '';
        if ( 'checked' == get_option( 'SSG-3danim-checkbox' ) ) {
            $checkboxvalue = 'checked';
        } else {
            $checkboxvalue = '';
        }
?>
        <div class="ssg-postbox" >
            <input type="checkbox" name="SSG-3danim-checkbox" value="checked" <?php echo $checkboxvalue; ?> />
             Activate 3D animated thumbnails in the image gallery<br />
        </div>
<?php
    }

        /*  Add checkbox to settings page  */
    
        function ssg_output_CDNchoice() {
            $checkboxvalue = '';
            if ( 'checked' == get_option( 'SSG-CDN-checkbox' ) ) {
                $checkboxvalue = 'checked';
            } else {
                $checkboxvalue = '';
            }
    ?>
            <div class="ssg-postbox" >
                <input type="checkbox" name="SSG-CDN-checkbox" value="checked" <?php echo $checkboxvalue; ?> />
                Faster loading of the newest SSG from <a href="https://www.jsdelivr.com/package/npm/story-show-gallery" target="_blank">
                JSdelivr</a> CDN - Recommended<br />
            </div>
    <?php
        }

    /* Adds SSG script and styles into Wordpress  */
    
    add_action( 'wp_enqueue_scripts', 'ssg_init' );

    function ssg_init() {
        $ssg_url = plugin_dir_url( __FILE__ );
        if ( 'checked' == get_option( 'SSG-CDN-checkbox' ) ) {
            wp_enqueue_script( 'ssg-js', 'https://cdn.jsdelivr.net/npm/story-show-gallery@2/dist/ssg.min.js', array( 'jquery' ), null, true );
            wp_enqueue_style( 'ssg-style', 'https://cdn.jsdelivr.net/npm/story-show-gallery@2/dist/ssg.min.css', array(), null, 'screen' );
        } else {
            wp_enqueue_script( 'ssg-js', $ssg_url.'ssg-js/ssg.min.js', array( 'jquery' ), null, true );
            wp_enqueue_style( 'ssg-style', $ssg_url.'ssg-js/ssg.min.css', array(), null, 'screen' );
        }
        wp_enqueue_script( 'ssg_cfg-js', $ssg_url.'ssg-js/ssg_cfg.js', array( 'ssg-js' ), null, true );
        if ( 'checked' == get_option( 'SSG-3danim-checkbox' ) ) {
            wp_enqueue_style( 'ssg-combo-style', $ssg_url.'ssg-js/3D-anim.min.css', array(), null, 'screen' );
        }
    }

    /* Admin styles  */

    add_action( 'admin_enqueue_scripts', 'ssg_add_admin_styles' );

    function ssg_add_admin_styles($hook) {
        $current_screen = get_current_screen();
        if ( false === strpos($current_screen->base, 'story-show-gallery') ) {
            return;
        } else {
            wp_enqueue_style( 'ssg_admin_css', plugins_url('css/ssg-admin.css',__FILE__ ) );
        }	
    }

    /* Add settings link to plugin page  */

    add_filter( 'plugin_action_links_'.plugin_basename(__FILE__), 'ssg_add_settings_link' );
    function ssg_add_settings_link( $links ) {
        $links[] = '<a href="' .
            admin_url( 'options-general.php?page=story-show-gallery' ) .
            '">' . __( 'Settings' ) . '</a>';
        return $links;
    }

    /* Set gallery shortcode to link to media file  */

    add_filter( 'shortcode_atts_gallery',
        function( $out ){
            $out['link'] = 'file'; 
            return $out;
        }
    );
?>
